summaryrefslogtreecommitdiffstats
path: root/kolf/kcomboboxdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolf/kcomboboxdialog.h')
-rw-r--r--kolf/kcomboboxdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kolf/kcomboboxdialog.h b/kolf/kcomboboxdialog.h
index 61b7ff2e..b55d68d1 100644
--- a/kolf/kcomboboxdialog.h
+++ b/kolf/kcomboboxdialog.h
@@ -98,13 +98,13 @@ public:
* @param ok Variable to store whether the user hit OK
* @param parent Parent widget for the dialog
* @param configName Name of the dialog for saving the completion and history
* @parma config KConfig for saving the completion and history
*/
static TQString getText(const TQString &_caption, const TQString &_text,
const TQString &_value = TQString(),
bool *ok = 0, TQWidget *parent = 0,
const TQString &configName = TQString(),
- KConfig *config = TDEGlobal::config());
+ TDEConfig *config = TDEGlobal::config());
protected:
KHistoryCombo *combo;
@@ -98,13 +98,13 @@ public:
* @param parent Parent widget for the dialog
* @param configName Name of the dialog for saving the completion and history
- * @parma config KConfig for saving the completion and history
+ * @parma config TDEConfig for saving the completion and history
*/
static TQString getText(const TQString &_caption, const TQString &_text,